Welcome to ClientVPS Mirrors

Help for package ARIMAANN
Type: Package
Title: Time Series Forecasting using ARIMA-ANN Hybrid Model
Version: 0.1.0
Depends: R (≥ 2.3.1), stats,forecast, tseries
Description: Testing, Implementation, and Forecasting of the ARIMA-ANN hybrid model. The ARIMA-ANN hybrid model combines the distinct strengths of the Auto-Regressive Integrated Moving Average (ARIMA) model and the Artificial Neural Network (ANN) model for time series forecasting.For method details see Zhang, GP (2003) <doi:10.1016/S0925-2312(01)00702-0>.
Encoding: UTF-8
License: GPL-3
NeedsCompilation: no
Packaged: 2022-10-12 14:07:24 UTC; pc
Author: Ramasubramanian V. [aut, ctb], Mrinmoy Ray [aut, cre]
Maintainer: Mrinmoy Ray <mrinmoy4848@gmail.com>
Repository: CRAN
Date/Publication: 2022-10-13 17:42:37 UTC

ARIMA-ANN hybrid model fitting

Description

The ARIMAANN function fit ARIMA-ANN hybrid model for time series data.

Usage

ARIMAANN(data,h)

Arguments

data

Input univariate time series (ts) data.

h

The forecast horizon.

Details

This package allows you to fit the ARIMA-ANN hybrid model.

Value

Test_Result

Checking the suitability of data for hybrid modelling

ARIMA coefficients

Coefficients of the fitted ARIMA

pvalues

pvalues of the fitted ARIMA model

ANN Summary

Summary of the fitted ANN model on residuals obtained from the fitted ARIMA model

MAPE

Mean Absolute Percentage Error (MAPE) of the fitted hybrid model

MSE

Mean Square Error (MSE) of fitted hybrid model

fitted

Fitted values of hybrid model

forecasted.values

h step ahead forecasted values employing hybrid model

Author(s)

Ramasubramanian V., Mrinmoy Ray

References

Zhang, G. P.Time series forecasting using a hybrid ARIMA and neural network model Neurocomputing, 50 (2003), pp. 159-175.

See Also

auto.arima, nnetar

Examples

data=lynx
ARIMAANN(data,5)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.